[PATCH] D137926: [Utils] Improved chunk-print-before-all.py script
Dmitry Bakunevich via Phabricator via llvm-commits
llvm-commits at lists.llvm.org
Mon Nov 21 03:55:51 PST 2022
dbakunevich updated this revision to Diff 476851.
Repository:
rG LLVM Github Monorepo
CHANGES SINCE LAST ACTION
https://reviews.llvm.org/D137926/new/
https://reviews.llvm.org/D137926
Files:
llvm/utils/chunk-print-before-all.py
Index: llvm/utils/chunk-print-before-all.py
===================================================================
--- llvm/utils/chunk-print-before-all.py
+++ llvm/utils/chunk-print-before-all.py
@@ -1,21 +1,24 @@
#!/usr/bin/env python
-# Given a -print-before-all -print-module-scope log from an opt invocation,
-# chunk it into a series of individual IR files, one for each pass invocation.
-# If the log ends with an obvious stack trace, try to split off a separate
-# "crashinfo.txt" file leaving only the valid input IR in the last chunk.
-# Files are written to current working directory.
-from __future__ import print_function
+# Given a -print-before-all and/or -print-after-all -print-module-scope log from
+# an opt invocation, chunk it into a series of individual IR files, one for each
+# pass invocation. If the log ends with an obvious stack trace, try to split off
+# a separate "crashinfo.txt" file leaving only the valid input IR in the last
+# chunk. Files are written to current working directory.
import sys
-basename = "chunk-"
chunk_id = 0
-def print_chunk(lines):
+# This function gets the pass name from the following line:
+# *** IR Dump Before/After PASS_NAME... ***
+def get_pass_name(line, prefix):
+ short_line = line[line.find(prefix) + len(prefix) + 1:]
+ return re.split(' |<', short_line)[0]
+
+def print_chunk(lines, prefix, pass_name):
global chunk_id
- global basename
- fname = basename + str(chunk_id) + ".ll"
+ fname = str(chunk_id) + "-" + prefix + "-" + pass_name + ".ll"
chunk_id = chunk_id + 1
print("writing chunk " + fname + " (" + str(len(lines)) + " lines)")
with open(fname, "w") as f:
@@ -26,11 +29,18 @@
for line in sys.stdin:
if line.startswith("*** IR Dump Before "):
if len(cur) != 0:
- print_chunk(cur);
+ print_chunk(cur, "before", pass_name)
+ cur = []
+ cur.append("; " + line)
+ pass_name = get_pass_name(line, "Before")
+ elif line.startswith("*** IR Dump After "):
+ if len(cur) != 0:
+ print_chunk(cur, "after", pass_name)
cur = []
cur.append("; " + line)
+ pass_name = get_pass_name(line, "After")
elif line.startswith("Stack dump:"):
- print_chunk(cur);
+ print_chunk(cur, "crash", pass_name)
cur = []
cur.append(line)
is_dump = True
@@ -42,4 +52,4 @@
with open("crashinfo.txt", "w") as f:
f.writelines(cur)
else:
- print_chunk(cur);
+ print_chunk(cur, "last", pass_name)
-------------- next part --------------
A non-text attachment was scrubbed...
Name: D137926.476851.patch
Type: text/x-patch
Size: 2562 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20221121/1e749474/attachment.bin>
More information about the llvm-commits
mailing list